@@ -478,6 +478,9 @@ class Fsdb(object):
         This must be set before the file is opened/read.
 
         Useful converted may include int, float, etc.
+
+        Note: if a converter throws an exception, a value of None will
+        be placed into the returned row instead.
         """
         return self._converters
 
@@ -663,8 +666,13 @@ class Fsdb(object):
 
     def _convert_array_values(self, row):
         for (n, converter) in enumerate(self._converters):
-            if converter is not None and row[n] is not None:
-                row[n] = converter(row[n])
+            if row[n] == "-" or row[n] == "":
+                row[n] = None
+            elif converter is not None and row[n] is not None:
+                try:
+                    row[n] = converter(row[n])
+                except Exception:
+                    row[n] = None
         return row
 
     def _next_as_array(self):
